@@ -1,12 +1,18 @@
 nbcosts <- function(nb, data, method=c("euclidean", "maximum", "manhattan",
                                 "canberra", "binary", "minkowski",
                                 "mahalanobis"), p=2, cov, inverted=FALSE) {
-  require(parallel)
-  clist <- mclapply(1:length(nb), function(i)
+# fix RSB 130902 nbcosts.R, prunecost.R
+  if (.Platform$OS.type == "windows") {
+    clist <- lapply(1:length(nb), function(i)
+      nbcost(data, i, nb[[i]], method, p, cov, inverted))
+  } else {
+    require(parallel)
+    clist <- mclapply(1:length(nb), function(i)
                     nbcost(data, i, nb[[i]], method,
                            p, cov, inverted),
                     mc.cores=ifelse(is.null(getOption('mc.cores')),
                         detectCores(), options('mc.cores')))
+  }
   attr(clist, "call") <- match.call()
   attr(clist, "class") <- "nbdist"
   return(clist)
